import sys
from pathlib import Path

sys.path.insert(0, str(Path.cwd().resolve()))

extensions = ['sphinx.ext.autodoc']

autodoc_mock_imports = [
    'dummy',
]

nitpicky = True
